@@ -2,7 +2,7 @@
 /**
  *  @brief The MeixnerDistribution distribution
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,6 @@
 #include "openturns/MeixnerDistribution.hxx"
 #include "openturns/RandomGenerator.hxx"
 #include "openturns/SpecFunc.hxx"
-#include "openturns/DistFunc.hxx"
 #include "openturns/PersistentObjectFactory.hxx"
 #include "openturns/TNC.hxx"
 #include "openturns/Brent.hxx"
@@ -39,7 +38,7 @@ static const Factory<MeixnerDistribution> Factory_MeixnerDistribution;
 
 /* Default constructor */
 MeixnerDistribution::MeixnerDistribution()
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , solver_(new TNC())
   , beta_(0.0)
   , alpha_(0.0)
@@ -59,7 +58,7 @@ MeixnerDistribution::MeixnerDistribution(const Scalar beta,
     const Scalar alpha,
     const Scalar delta,
     const Scalar mu)
-  : ContinuousDistribution()
+  : DistributionImplementation()
   , solver_(new TNC())
   , beta_(0.0)
   , alpha_(0.0)
@@ -224,7 +223,6 @@ void MeixnerDistribution::computeRange()
   }
   // Find the numerical upper bound based on the PDF value
   Point upperBound(mu);
-  Point stepUpper(sigma);
   Scalar logPDFUpper = logPDF;
   while (logPDFUpper > logPDFEpsilon)
   {
@@ -407,6 +405,50 @@ void MeixnerDistribution::update()
   dc_ = solver.getResult().getOptimalValue()[0] - c_;
 }
 
+/* Build a C1 interpolation of the CDF function */
+Collection<PiecewiseHermiteEvaluation> MeixnerDistribution::interpolateCDF(const UnsignedInteger n)
+{
+  const PDFWrapper pdfWrapper(this);
+  const Scalar xMin = getRange().getLowerBound()[0];
+  const Scalar xMax = getRange().getUpperBound()[0];
+  const Scalar mu = getMean()[0];
+  Point locationsCDF(n);
+  Point locationsCCDF(n);
+  Point valuesCDF(n);
+  Point valuesCCDF(n);
+  Point derivativesCDF(n);
+  Point derivativesCCDF(n);
+  Scalar xCDFOld = xMin;
+  Scalar xCCDFOld = xMax;
+  locationsCDF[0] = xMin;
+  locationsCCDF[n - 1] = xMax;
+  GaussKronrod algo;
+  const Scalar stepCDF = (mu - xMin) / (n - 1.0);
+  const Scalar stepCCDF = (xMax - mu) / (n - 1.0);
+  for (UnsignedInteger i = 1; i < n; ++i)
+  {
+    const Scalar xCDF = xMin + i * stepCDF;
+    const Scalar xCCDF = xMax - i * stepCCDF;
+    locationsCDF[i] = xCDF;
+    locationsCCDF[n - i - 1] = xCCDF;
+    Point ai;
+    Point bi;
+    Sample fi;
+    Point ei;
+    Scalar error = -1.0;
+    valuesCDF[i] = valuesCDF[i - 1] + algo.integrate(pdfWrapper, xCDFOld, xCDF, error, ai, bi, fi, ei)[0];
+    valuesCCDF[n - i - 1] = valuesCCDF[n - i] + algo.integrate(pdfWrapper, xCCDF, xCCDFOld, error, ai, bi, fi, ei)[0];
+    derivativesCDF[i] = computePDF(xCDF);
+    derivativesCCDF[n - i - 1] = -computePDF(xCCDF);
+    xCDFOld = xCDF;
+    xCCDFOld = xCCDF;
+  }
+  Collection<PiecewiseHermiteEvaluation> coll(2);
+  coll[0] = PiecewiseHermiteEvaluation(locationsCDF, valuesCDF, derivativesCDF);
+  coll[1] = PiecewiseHermiteEvaluation(locationsCCDF, valuesCCDF, derivativesCCDF);
+  return coll;
+}
+
 /* Get one realization of the distribution
    We use the ratio-of-uniform method:
    if b=\sup_x \sqrt{p(x)}, c=\inf_x x\sqrt{p(x)}, d=\sup_x x\sqrt{p(x)}
@@ -461,6 +503,8 @@ Scalar MeixnerDistribution::computeComplementaryCDF(const Point & point) const
 Scalar MeixnerDistribution::computeScalarQuantile(const Scalar prob,
     const Bool tail) const
 {
+  if (!((prob >= 0.0) && (prob <= 1.0)))
+    throw InvalidArgumentException(HERE) << "computeScalarQuantile expected prob to belong to [0,1], but is " << prob;
   const Scalar a = getRange().getLowerBound()[0];
   const Scalar b = getRange().getUpperBound()[0];
   if (prob <= 0.0) return (tail ? b : a);
@@ -604,7 +648,7 @@ Bool MeixnerDistribution::isElliptical() const
 /* Method save() stores the object through the StorageManager */
 void MeixnerDistribution::save(Advocate & adv) const
 {
-  ContinuousDistribution::save(adv);
+  DistributionImplementation::save(adv);
   adv.saveAttribute( "beta_", beta_ );
   adv.saveAttribute( "alpha_", alpha_ );
   adv.saveAttribute( "delta_", delta_ );
@@ -615,7 +659,7 @@ void MeixnerDistribution::save(Advocate & adv) const
 /* Method load() reloads the object from the StorageManager */
 void MeixnerDistribution::load(Advocate & adv)
 {
-  ContinuousDistribution::load(adv);
+  DistributionImplementation::load(adv);
   adv.loadAttribute( "beta_", beta_ );
   adv.loadAttribute( "alpha_", alpha_ );
   adv.loadAttribute( "delta_", delta_ );
