@@ -2,7 +2,7 @@
 /**
  *  @brief VisualTest implements statistical tests
  *
- *  Copyright 2005-2023 Airbus-EDF-IMACS-ONERA-Phimeca
+ *  Copyright 2005-2024 Airbus-EDF-IMACS-ONERA-Phimeca
  *
  *  This library is free software: you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License as published by
@@ -297,6 +297,39 @@ GridLayout VisualTest::DrawPairs(const Sample & sample)
   return grid;
 }
 
+/* Draw 2-d projections of a multivariate sample */
+GridLayout VisualTest::DrawPairsXY(const Sample & sampleX, const Sample & sampleY)
+{
+  const UnsignedInteger sampleXDimension = sampleX.getDimension();
+  const UnsignedInteger sampleYDimension = sampleY.getDimension();
+
+  GridLayout grid(sampleYDimension, sampleXDimension);
+  const Description sampleXDescription(sampleX.getDescription());
+  const Description sampleYDescription(sampleY.getDescription());
+
+  if (sampleX.getSize() != sampleY.getSize())
+    throw InvalidRangeException(HERE) << "The two samples must have the same size.";
+
+  for (UnsignedInteger i = 0; i < sampleYDimension; ++ i)
+  {
+    for (UnsignedInteger j = 0; j < sampleXDimension; ++ j)
+    {
+      Cloud cloud(sampleX.getMarginal(j), sampleY.getMarginal(i));
+
+      Graph graph("", i == sampleYDimension - 1 ? sampleXDescription[j] : "", j == 0 ? sampleYDescription[i] : "", true, "topright");
+      graph.add(cloud);
+      int location = GraphImplementation::TICKNONE;
+      if (i == sampleYDimension - 1)
+        location |= GraphImplementation::TICKX;
+      if (j == 0)
+        location |= GraphImplementation::TICKY;
+      graph.setTickLocation(static_cast<GraphImplementation::TickLocation>(location));
+      grid.setGraph(i, j, graph);
+    }
+  }
+  return grid;
+}
+
 
 /* Draw 2-d projections of a multivariate sample, plus marginals of a distribution */
 GridLayout VisualTest::DrawPairsMarginals(const Sample & sample, const Distribution & distribution)
@@ -704,4 +737,37 @@ Graph VisualTest::DrawLowerExtremalDependenceFunction(const Sample & data)
   return result;
 }
 
+/** Draw the sample as a cloud of points in or out of the domain */
+GridLayout VisualTest::DrawInsideOutside(const Domain & domain,
+    const Sample & sample,
+    const String & inColor,
+    const String & outColor)
+{
+  if (!(sample.getDimension() >= 2)) throw InvalidArgumentException(HERE) << "Error: cannot draw sample of dimension=" << sample.getDimension() << " less than 2.";
+  Sample insideSample(0, sample.getDimension()), outsideSample(0, sample.getDimension());
+  for (UnsignedInteger i = 0; i < sample.getSize(); i++)
+  {
+    if (domain.contains(sample[i]))
+      insideSample.add(sample[i]);
+    else
+      outsideSample.add(sample[i]);
+  }
+  GridLayout grid(sample.getDimension() - 1, sample.getDimension() - 1);
+  grid.setTitle("Points inside and outside the domain");
+  for (UnsignedInteger iX = 0; iX < sample.getDimension(); iX++)
+  {
+    for (UnsignedInteger iY = iX + 1; iY < sample.getDimension(); iY++)
+    {
+      Sample in2DSample(insideSample.getMarginal(Indices({ iX, iY }))), out2DSample(outsideSample.getMarginal(Indices({ iX, iY })));
+      Graph graph("", iY + 1 == sample.getDimension() ? (OSS() << "x" << iX).str() : "", iX == 0 ? (OSS() << "x" << iY).str() : "", true);
+      graph.add(Cloud(in2DSample, inColor, "plus", "In"));
+      graph.add(Cloud(out2DSample, outColor, "plus", "Out"));
+      if (iX == 0 && iY == 1)
+        graph.setLegendPosition("topright");
+      grid.setGraph(iY - 1, iX, graph);
+    }
+  }
+  return grid;
+}
+
 END_NAMESPACE_OPENTURNS
